@@ -30,6 +30,10 @@ class ConfigAlgo(Config):
         default="ext4",
         help_string="what file systems to check",
     )
+    increase_percent = ParamCreator.create_int(
+        default="50",
+        help_string="By how much to increase (in percentiles)",
+    )
 
 
 class ConfigProxy(Config):
